# -*- coding: UTF-8 -*-
"""
Supported CAPTCHAs
~~~~~~~~~~~~~~~~~~
"""

# pylint: disable=unused-import,import-error
from ._captcha import ImageCaptcha, TextCaptcha, RecaptchaV2, RecaptchaV3
from ._captcha import HCaptcha, FunCaptcha, KeyCaptcha, GeeTest, Capy, TikTokCaptcha
from ._captcha import CaptchaType
